@@ -4,7 +4,7 @@ The AhbExpressionTransformer defines the rules how the different parts of the pa
 
 The used terms are defined in the README.md.
 """
-from typing import Awaitable, Dict, List, Union
+from typing import Awaitable, Dict, List, Optional, Union
 
 from lark import Token, Transformer, Tree, v_args
 from lark.exceptions import VisitError
@@ -30,6 +30,8 @@ _str_to_modal_mark_mapping: Dict[str, ModalMark] = {
 
 
 # pylint: disable=no-self-use, invalid-name
+# no-self-use: The following methods are not static because it refers to the terminals of the lark grammar.
+# invalid-name: That's also the reason why they seemingly violate the naming conventions.
 class AhbExpressionTransformer(Transformer):
     """
     Transformer, that evaluates the trees built from the ahb expressions.
@@ -38,7 +40,7 @@ class AhbExpressionTransformer(Transformer):
     their respective condition expressions already evaluated to booleans.
     """
 
-    def __init__(self, entered_input: str):
+    def __init__(self, entered_input: Optional[str]):
         """
         The input are the evaluated format constraint conditions in the form of ConditionNodes.
 
@@ -130,7 +132,7 @@ class AhbExpressionTransformer(Transformer):
             Union[AhbExpressionEvaluationResult, Awaitable[AhbExpressionEvaluationResult]]
         ],
     ) -> AhbExpressionEvaluationResult:
-        # the thing is that some user funcs (like f.e. 'requirement_indicator' are not async and there's no reason to
+        # the thing is that some user funcs (like e.g. 'requirement_indicator') are not async and there's no reason to
         # make them async. So here we have a list that is mixed: It contains both evaluation results and awaitable
         # evaluation results. The utility function 'gather_if_necessary' accounts for that (see its separate tests).
         results = await gather_if_necessary(list_of_single_requirement_indicator_expressions)
@@ -148,7 +150,9 @@ class AhbExpressionTransformer(Transformer):
         return results[-1]
 
 
-async def evaluate_ahb_expression_tree(parsed_tree: Tree, entered_input: str) -> AhbExpressionEvaluationResult:
+async def evaluate_ahb_expression_tree(
+    parsed_tree: Tree, entered_input: Optional[str]
+) -> AhbExpressionEvaluationResult:
     """
     Evaluates the tree built from the ahb expressions with the help of the AhbExpressionTransformer.
 
